@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.9.4/apps/dwmwhat/dwmwhat.cc 8496 $
+// @(#) $DwmPath: dwm/libDwm/trunk/apps/dwmwhat/dwmwhat.cc 8496 $
 // @(#) $Id: dwmwhat.cc 8496 2016-05-08 04:55:39Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
@@ -54,10 +54,9 @@ extern "C" {
 #include <utility>  // for std::pair
 
 #include "DwmOptArgs.hh"
+#include "DwmPackageInfo.hh"
 #include "DwmSvnTag.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.9.4/apps/dwmwhat/dwmwhat.cc 8496 $");
-
 using namespace std;
 
 static bool g_shortOption = false;
@@ -107,7 +106,10 @@ static void LineMatch(const string & line, const string & tagName)
       }
     }
     else {
-      cout << lookMatch[0] << '\n';
+      string  s(regex_replace(lookMatch[0].str(),regex("^\\@\\(#\\) *"), ""));
+      if (! s.empty()) {
+        cout << s << '\n';
+      }
     }
   }
   return;
@@ -174,7 +176,8 @@ int main(int argc, char *argv[])
   int  nextArg = optArgs.Parse(argc, argv);
 
   if (optArgs.Get<bool>('v')) {
-    cout << svntag.TagName() << '\n';
+    cout << Dwm::PackageInfo::Name() << '-'
+         << Dwm::PackageInfo::Version() << '\n';
     return 0;
   }
 
