@@ -1,7 +1,7 @@
 //===========================================================================
 // @(#) $DwmPath$
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2023
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -512,7 +512,51 @@ namespace Dwm {
     }
     return(rc);
   }
-  
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Ipv4Prefix::Read(boost::asio::ip::tcp::socket & s,
+                        boost::system::error_code & ec)
+  { return ASIO_Read(s, ec); }
+    
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Ipv4Prefix::Write(boost::asio::ip::tcp::socket & s,
+                         boost::system::error_code & ec) const
+  { return ASIO_Write(s, ec); }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Ipv4Prefix::Read(boost::asio::local::stream_protocol::socket & s,
+                        boost::system::error_code & ec)
+  { return ASIO_Read(s, ec); }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool
+  Ipv4Prefix::Write(boost::asio::local::stream_protocol::socket & s,
+                    boost::system::error_code & ec) const
+  { return ASIO_Write(s, ec); }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Ipv4Prefix::Read(boost::asio::generic::stream_protocol::socket & s,
+                        boost::system::error_code & ec)
+  { return ASIO_Read(s, ec); }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool
+  Ipv4Prefix::Write(boost::asio::generic::stream_protocol::socket & s,
+                    boost::system::error_code & ec) const
+  { return ASIO_Write(s, ec); }
+
   //--------------------------------------------------------------------------
   //  
   //--------------------------------------------------------------------------
